use cgmath::Point2;

use crate::{ObjectSprite, ParticleBuilder, UiSprite};

/// Bundles parameters passed to a single call to GPUState::render
pub struct FrameState<'a> {
	/// Camera position, in world units
	pub camera_pos: Point2<f32>,

	/// Height of screen, in world units
	pub camera_zoom: f32,

	/// World object sprites
	pub object_sprites: Vec<ObjectSprite>,

	/// UI sprites
	pub ui_sprites: Vec<UiSprite>,

	/// Particles to create during this frame.
	/// this array will be cleared.
	pub new_particles: &'a mut Vec<ParticleBuilder>,

	// TODO: handle overflow
	/// The current time, in seconds
	pub current_time: f32,
}
